@@ -2,63 +2,12 @@ import json
 from collections import defaultdict
 from concurrent import futures
 from copy import deepcopy
-import os
 # Non standard libraries
 import pandas as pd
-from pathlib import Path
 from launchpy import config, connector
 from typing import IO, Union
 from .library import Library
-
-def saveFile(data:str,filename:str=None,type:str='txt',encoding:str='utf-8')->None:
-    """
-    Save file to your system.
-    Arguments:
-        data : REQUIRED : data to be saved
-        filename : REQUIRED : name of the file or the path
-        type : OPTIONAL : Can be "txt", "json", "js"
-            json
-    """
-    if type=="txt":
-        if '.txt' not in filename:
-            filename = f"{filename}.txt"
-        with open(Path(filename),'w',encoding=encoding) as f:
-            f.write(data)
-    elif type == "js":
-        if '.js' not in filename:
-            filename = f"{filename}.js"
-        with open(Path(filename),'w',encoding=encoding) as f:
-            f.write(data)
-    elif type=="json":
-        if '.json' not in filename:
-            filename = f"{filename}.json"
-        with open(Path(filename),'w',encoding=encoding) as f:
-            f.write(json.dumps(data,indent=4))
-
-
-def createConfigFile(scope: str = "https://ims-na1.adobelogin.com/s/ent_reactor_admin_sdk", verbose: object = False)->None:
-    """
-    This function will create a 'config_admin.json' file where you can store your access data. 
-    Arguments:
-        scope: OPTIONAL : if you have problem with scope during API connection, you may need to update this.
-            scope="https://ims-na1.adobelogin.com/s/ent_reactor_admin_sdk"
-            or 
-            scope="https://ims-na1.adobelogin.com/s/ent_reactor_sdk"
-    """
-    json_data = {
-        'org_id': '<orgID>',
-        'client_id': "<client_id>",
-        'tech_id': "<something>@techacct.adobe.com",
-        'secret': "<YourSecret>",
-        'pathToKey': '<path/to/your/privatekey.key>',
-        'scope': scope
-    }
-    with open('config_admin.json', 'w') as cf:
-        cf.write(json.dumps(json_data, indent=4))
-    if verbose:
-        print(
-            f" file created at this location : {os.getcwd()}{os.sep}config_admin.json")
-
+from .configs import saveFile
 
 class Property:
     """
@@ -608,7 +557,7 @@ class Property:
             data = extensions
         return data
 
-    def createRules(self, name: str)->object:
+    def createRule(self, name: str)->object:
         """
         Create a rule by provided a rule name.
         Arguments:
@@ -632,7 +581,7 @@ class Property:
             data = rules
         return data
 
-    def createRuleComponents(self, name: str, settings: str = None, descriptor: str = None, extension_infos: dict = None, rule_infos: dict = None, **kwargs)->object:
+    def createRuleComponent(self, name: str, settings: str = None, descriptor: str = None, extension_infos: dict = None, rule_infos: dict = None, **kwargs)->object:
         """
         Create a ruleComponent by provided a rule name and descriptor (minimum). It returns an object.
         It takes additional information in order to link the ruleCompoment to a rule and with an Extension.
@@ -644,8 +593,9 @@ class Property:
             rule_infos : REQUIRED : rule information link to that rule component (dictionary with "data", "id" and "type")
             (can be found from translator)
             settings : OPTIONAL : settings for that rule component
+        possible kwargs:
+            order : the order of the rule component        
         """
-
         obj = {
             "data": {
                 "attributes": {
@@ -672,7 +622,7 @@ class Property:
             data = rc
         return data
 
-    def createDataElements(self, name: str, settings: str = None, descriptor: str = None, extension: dict = None, **kwargs: dict)->object:
+    def createDataElement(self, name: str, settings: str = None, descriptor: str = None, extension: dict = None, **kwargs: dict)->object:
         """
         Create Data Elements following the usage of required arguments. 
         Arguments: 
@@ -865,22 +815,27 @@ class Property:
 
     def getRevisions(self,element:dict=None)->list:
         """
-        Get the latest revisions of an elements.
+        Get the revisions of an element.
         Arguments:
             element : REQUIRED : the element definition dictionary
         """
         if element is None or type(element) != dict:
             raise ValueError("element must be a definition")
-        revisionURL = element['relationships'].get('rule_components',{}).get('links',{}).get('related','unknown')
+        revisionURL = element['relationships'].get('revisions',{}).get('links',{}).get('related','unknown')
         if revisionURL == "unknown":
             raise Exception("could not find a revision link in the element")
-        firstRevision = self.getRessource(revisionURL)
-        metaLastPage = firstRevision['meta'].get('pagination',{}).get('total_pages')
-        if metaLastPage == firstRevision['meta'].get('pagination',{}).get('current_page'):
-            return firstRevision['data']
-        else:
-            lastRevision = self.getRessource(revisionURL,params={"page[number]":metaLastPage})
-            return lastRevision['data']
+        data = []
+        params = {"page[number]":0}
+        lastPage = False
+        while lastPage == False:
+            params["page[number]"] += 1
+            revision = self.getRessource(revisionURL,params=params)
+            data += revision['data']
+            metaLastPage = revision['meta'].get('pagination',{}).get('total_pages')
+            if metaLastPage == revision['meta'].get('pagination',{}).get('current_page'):
+                lastPage=True
+        return data
+
 
 
     def reviseDataElements(self, dataElement_id: str)->dict:
@@ -1000,7 +955,7 @@ class Property:
         return res
 
 
-    def updateDataElements(self, dataElement_id: str, attr_dict: object, **kwargs)->object:
+    def updateDataElement(self, dataElement_id: str, attr_dict: object, **kwargs)->object:
         """
         Update the data element information based on the information provided.
         arguments: 
